@@ -58,6 +58,5 @@ protected:
     bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
 
 private:
-    AkonadiBrowserModel *mBrowserModel;
+    AkonadiBrowserModel *const mBrowserModel;
 };
-
