@@ -8,7 +8,7 @@
 #include "akonadiconsole_debug.h"
 #include "debugmodel.h"
 
-#include <KCheckComboBox>
+#include <Libkdepim/KCheckComboBox>
 #include <chrono>
 
 using namespace std::chrono_literals;
@@ -27,9 +27,7 @@ DebugFilterModel::DebugFilterModel(QObject *parent)
     connect(&mInvalidateTimer, &QTimer::timeout, this, &DebugFilterModel::invalidate);
 }
 
-DebugFilterModel::~DebugFilterModel()
-{
-}
+DebugFilterModel::~DebugFilterModel() = default;
 
 void DebugFilterModel::setSenderFilter(KCheckComboBox *senderFilter)
 {
